@@ -33,7 +33,7 @@ further details.
 # - rework under assumption that there is only one DB
 #==================================================================
 __author__ = "Karsten.Hilbert@gmx.net"
-__license__ = "GPL"
+__license__ = "GPL v2 or later"
 
 # standard library
 import sys, string, os.path, fileinput, os, time, getpass, glob, re as regex, tempfile, logging
@@ -79,9 +79,6 @@ from Gnumed.pycommon.gmExceptions import ConstructorError
 import gmAuditSchemaGenerator
 aud_gen = gmAuditSchemaGenerator
 
-import gmNotificationSchemaGenerator
-notify_gen = gmNotificationSchemaGenerator
-
 
 _log = logging.getLogger('gm.bootstrapper')
 _cfg = gmCfg2.gmCfgData()
@@ -182,44 +179,13 @@ ALTER TABLE %(src_schema)s.%(src_tbl)s
 		ON DELETE RESTRICT
 ;"""
 
-SQL_sanity_check_trigger_func = u"""
-DROP FUNCTION IF EXISTS clin.trf_sanity_check_enc_epi_insert() CASCADE;
+SQL_add_index = u"""
+-- idempotent:
+DROP INDEX IF EXISTS %(idx_schema)s.%(idx_name)s CASCADE;
 
-create function clin.trf_sanity_check_enc_epi_insert()
-	returns trigger
-	 language 'plpgsql'
-	as '
-declare
-	_identity_from_encounter integer;
-	_identity_from_episode integer;
-begin
-	-- sometimes .fk_episode can actually be NULL (eg. clin.substance_intake)
-	-- in which case we do not need to run the sanity check
-	if NEW.fk_episode is NULL then
-		return NEW;
-	end if;
+CREATE INDEX %(idx_name)s ON %(idx_schema)s.%(idx_table)s(%(idx_col)s);
+"""
 
-	select fk_patient into _identity_from_encounter from clin.encounter where pk = NEW.fk_encounter;
-
-	select fk_patient into _identity_from_episode from clin.encounter where pk = (
-		select fk_encounter from clin.episode where pk = NEW.fk_episode
-	);
-
-	if _identity_from_encounter <> _identity_from_episode then
-		raise exception ''INSERT into %.%: Sanity check failed. Encounter % patient = %. Episode % patient = %.'',
-			TG_TABLE_SCHEMA,
-			TG_TABLE_NAME,
-			NEW.fk_encounter,
-			_identity_from_encounter,
-			NEW.fk_episode,
-			_identity_from_episode
-		;
-		return NULL;
-	end if;
-
-	return NEW;
-end;
-';"""
 
 #==================================================================
 def user_exists(cursor=None, user=None):
@@ -656,6 +622,11 @@ class database:
 			return False
 		curs.close()
 
+		# reindex db so upgrade doesn't fail on broken index
+		if not self.reindex_all():
+			_log.error('cannot REINDEX cloned target database')
+			return False
+
 		tmp = cfg_get(self.section, 'superuser schema')
 		if tmp is not None:
 			if not _import_schema(group=self.section, schema_opt='superuser schema', conn=self.conn):
@@ -806,7 +777,7 @@ class database:
 			if drop_existing:
 				print_msg("==> dropping pre-existing target database [%s] ..." % self.name)
 				_log.info('trying to drop target database')
-				cmd = 'drop database "%s"' % self.name
+				cmd = 'DROP DATABASE "%s"' % self.name
 				self.conn.set_isolation_level(0)
 				cursor = self.conn.cursor()
 				try:
@@ -821,7 +792,7 @@ class database:
 				use_existing = bool(int(cfg_get(self.section, 'use existing target database')))
 				if use_existing:
 					# FIXME: verify that database is owned by "gm-dbo"
-					print_msg("==> using pre-existing *target* database [%s] ..." % self.name)
+					print_msg("==> using pre-existing target database [%s] ..." % self.name)
 					_log.info('using existing database [%s]', self.name)
 					return True
 				else:
@@ -830,39 +801,49 @@ class database:
 
 		tablespace = cfg_get(self.section, 'tablespace')
 		if tablespace is None:
-			cmd = """
-				create database \"%s\" with
+			create_db_cmd = """
+				CREATE DATABASE \"%s\" with
 					owner = \"%s\"
 					template = \"%s\"
 					encoding = 'unicode'
 				;""" % (self.name, self.owner.name, self.template_db)
 		else:
-			cmd = """
-				create database \"%s\" with
+			create_db_cmd = """
+				CREATE DATABASE \"%s\" with
 					owner = \"%s\"
 					template = \"%s\"
 					encoding = 'unicode'
 					tablespace = '%s'
 				;""" % (self.name, self.owner.name, self.template_db, tablespace)
 
-		# create database
+		# create DB must be run outside transactions
+		old_iso = self.conn.isolation_level
 		self.conn.set_isolation_level(0)
 		cursor = self.conn.cursor()
-		cursor.execute("select pg_size_pretty(pg_database_size('%s'))" % self.template_db)
+
+		# get size
+		size_cmd = "SELECT pg_size_pretty(pg_database_size('%s'))" % self.template_db
+		cursor.execute(size_cmd)
 		size = cursor.fetchone()[0]
+
+		# create database by cloning
 		print_msg("==> cloning [%s] (%s) as target database [%s] ..." % (self.template_db, size, self.name))
 		try:
-			cursor.execute(cmd)
+			cursor.execute(create_db_cmd)
 		except:
-			_log.exception(">>>[%s]<<< failed" % cmd)
+			_log.exception(">>>[%s]<<< failed" % create_db_cmd)
 			cursor.close()
+			self.conn.set_isolation_level(old_iso)
 			return False
 		cursor.close()
+
 		self.conn.commit()
+		self.conn.set_isolation_level(old_iso)
 
 		if not self.__db_exists():
 			return None
 		_log.info("Successfully created GNUmed database [%s]." % self.name)
+
 		return True
 	#--------------------------------------------------------------
 	def check_data_plausibility(self):
@@ -1053,9 +1034,9 @@ class database:
 				_log.exception('cannot remove data import script module [%s], hoping for the best', import_script)
 
 		return True
+
 	#--------------------------------------------------------------
 	def verify_result_hash(self):
-		# verify template database hash
 		print_msg("==> verifying target database schema ...")
 		target_version = cfg_get(self.section, 'target version')
 		if target_version == 'devel':
@@ -1074,6 +1055,25 @@ class database:
 		_log.error('target database identity hash invalid')
 		print_msg("    ... failed (hash mismatch)")
 		return False
+
+	#--------------------------------------------------------------
+	def reindex_all(self):
+		print_msg("==> reindexing target database ...")
+		_log.info('REINDEXing cloned target database so upgrade does not fail because of a broken index')
+		old_iso = self.conn.isolation_level
+		self.conn.set_isolation_level(0)
+		curs = self.conn.cursor()
+		cmd = 'REINDEX DATABASE %s' % self.name
+		try:
+			curs.execute(cmd)
+		except:
+			_log.exception(">>>[%s]<<< failed" % cmd)
+			curs.close()
+			self.conn.set_isolation_level(old_iso)
+			return False
+		curs.close()
+		self.conn.set_isolation_level(old_iso)
+		return True
 	#--------------------------------------------------------------
 	def transfer_users(self):
 		print_msg("==> transferring users ...")
@@ -1163,7 +1163,7 @@ class database:
 	def bootstrap_notifications(self):
 
 		# setup clin.clin_root_item child tables FK's
-		print_msg("==> verifying FKs on clin.clin_root_item child tables ...")
+		print_msg("==> setting up encounter/episode FKs and IDXs ...")
 		child_tables = gmPG2.get_child_tables(link_obj = self.conn, schema = 'clin', table = 'clin_root_item')
 		_log.info('clin.clin_root_item child tables:')
 		for child in child_tables:
@@ -1180,7 +1180,6 @@ class database:
 				target_column = 'pk',
 			)
 			if len(FKs) > 0:
-				#_log.info('%s FK(s) exist: [#1 = %s.%s] %s.%s.fk_episode -> clin.episode.pk', len(FKs), FKs[0]['constraint_schema'], FKs[0]['constraint_name'], child['namespace'], child['table'])
 				_log.info('%s FK(s) exist:', len(FKs))
 				for idx in range(len(FKs)):
 					FK = FKs[idx]
@@ -1196,6 +1195,22 @@ class database:
 					'target_col': 'pk'
 				}
 				gmPG2.run_rw_queries(link_obj = self.conn, queries = [{'cmd': cmd}])
+			# index on .fk_episode
+			idx_defs = gmPG2.get_index_name(indexed_table = u'%s.%s' % (child['namespace'], child['table']), indexed_column = u'fk_episode', link_obj = self.conn)
+			# drop any existing
+			for idx_def in idx_defs:
+				_log.info(u'dropping index %s.%s', idx_def['index_schema'], idx_def['index_name'])
+				cmd = u'DROP INDEX IF EXISTS %s.%s CASCADE' % (idx_def['index_schema'], idx_def['index_name'])
+				gmPG2.run_rw_queries(link_obj = self.conn, queries = [{'cmd': cmd}])
+			# create
+			_log.info(u'creating index idx_%s_%s_fk_episode', child['namespace'], child['table'])
+			cmd = SQL_add_index % {
+				'idx_schema': child['namespace'],
+				'idx_name': u'idx_%s_%s_fk_episode' % (child['namespace'], child['table']),
+				'idx_table': child['table'],
+				'idx_col': u'fk_episode'
+			}
+			gmPG2.run_rw_queries(link_obj = self.conn, queries = [{'cmd': cmd}])
 
 			# .fk_encounter
 			FKs = gmPG2.get_foreign_key_names (
@@ -1208,7 +1223,6 @@ class database:
 				target_column = 'pk'
 			)
 			if len(FKs) > 0:
-				#_log.info('%s FK(s) exist: [#1 = %s.%s] %s.%s.fk_encounter -> clin.encounter.pk', len(FKs), FKs[0]['constraint_schema'], FKs[0]['constraint_name'], child['namespace'], child['table'])
 				_log.info('%s FK(s) exist:', len(FKs))
 				for idx in range(len(FKs)):
 					FK = FKs[idx]
@@ -1224,23 +1238,42 @@ class database:
 					'target_col': 'pk'
 				}
 				gmPG2.run_rw_queries(link_obj = self.conn, queries = [{'cmd': cmd}])
+			# index on .fk_encounter
+			idx_defs = gmPG2.get_index_name(indexed_table = u'%s.%s' % (child['namespace'], child['table']), indexed_column = u'fk_encounter', link_obj = self.conn)
+			# drop any existing
+			for idx_def in idx_defs:
+				_log.info(u'dropping index %s.%s', idx_def['index_schema'], idx_def['index_name'])
+				cmd = u'DROP INDEX IF EXISTS %s.%s CASCADE' % (idx_def['index_schema'], idx_def['index_name'])
+				gmPG2.run_rw_queries(link_obj = self.conn, queries = [{'cmd': cmd}])
+			# create
+			_log.info(u'creating index idx_%s_%s_fk_encounter', child['namespace'], child['table'])
+			cmd = SQL_add_index % {
+				'idx_schema': child['namespace'],
+				'idx_name': u'idx_%s_%s_fk_encounter' % (child['namespace'], child['table']),
+				'idx_table': child['table'],
+				'idx_col': u'fk_encounter'
+			}
+			gmPG2.run_rw_queries(link_obj = self.conn, queries = [{'cmd': cmd}])
+
+		curs = self.conn.cursor()
+
+		# re-create fk_encounter/fk_episode sanity check triggers on all tables
+		if gmPG2.function_exists(link_obj = curs, schema = u'gm', function = u'create_all_enc_epi_sanity_check_triggers'):
+			print_msg("==> setting up encounter/episode FK sanity check triggers ...")
+			_log.debug('attempting to set up sanity check triggers on all tables linking to encounter AND episode')
+			cmd = u'select gm.create_all_enc_epi_sanity_check_triggers()'
+			curs.execute(cmd)
+			result = curs.fetchone()
+			if result[0] is False:
+				_log.error('error creating sanity check triggers on all tables linking to clin.encounter AND clin.episode')
+				curs.close()
+				return None
 
 		# always re-create generic super signal (if exists)
-		print_msg("==> setting up generic notifications ...")
-		_log.debug('creating generic modification announcement triggers on all registered tables')
-		curs = self.conn.cursor()
-		cmd = u"""
-			SELECT EXISTS (
-				SELECT 1 FROM information_schema.routines WHERE
-					routine_name = 'create_all_table_mod_triggers'
-						AND
-					routine_schema = 'gm'
-			)"""
-		curs.execute(cmd)
-		result = curs.fetchone()
-		if result[0] is True:
-			_log.debug('creating generic modification announcement triggers on registered tables')
-			curs.execute(SQL_sanity_check_trigger_func)
+		if gmPG2.function_exists(link_obj = curs, schema = u'gm', function = u'create_all_table_mod_triggers'):
+			print_msg("==> setting up generic notifications ...")
+			_log.debug('attempting to create generic modification announcement triggers on all registered tables')
+
 			cmd = u"SELECT gm.create_all_table_mod_triggers(True::boolean)"
 			curs.execute(cmd)
 			result = curs.fetchone()
@@ -1248,49 +1281,8 @@ class database:
 			if result[0] is False:
 				_log.error('cannot create generic modification announcement triggers on all tables')
 				return None
-		else:
-			curs.close()
-			_log.debug('NOT creating generic modification announcement triggers, functionality not available')
 
-		print_msg("==> setting up (old style) notifications ...")
-		# get configuration
-		tmp = cfg_get(self.section, 'notification disable')
-		# if this option is not given, assume we want notification
-		if tmp is not None:
-			# if we don't want notification on these tables, return without error
-			if int(tmp) == 1:
-				print_msg('    ... skipped (disabled)')
-				return True
-
-		# create notification schema
-		curs = self.conn.cursor()
-		notification_schema = notify_gen.create_notification_schema(curs)
-		notification_schema.extend(notify_gen.create_narrative_notification_schema(curs))
-		curs.close()
-		if notification_schema is None:
-			_log.error('cannot generate notification schema for GNUmed database [%s]' % self.name)
-			return None
-
-		# write schema to file
-		tmpfile = os.path.join(tempfile.gettempdir(), 'notification-schema.sql')
-		file = open (tmpfile, 'wb')
-		for line in notification_schema:
-			file.write("%s;\n" % line)
-		file.close()
-
-		# import notification schema
-		psql = gmPsql.Psql(self.conn)
-		if psql.run(tmpfile) != 0:
-			_log.error("cannot import notification schema definition for database [%s]" % (self.name))
-			return None
-
-		if _keep_temp_files:
-			return True
-
-		try:
-			os.remove(tmpfile)
-		except StandardError:
-			_log.exception('cannot remove notification schema file [%s]' % tmpfile)
+		self.conn.commit()
 		return True
 #==================================================================
 class gmBundle:
@@ -1643,8 +1635,8 @@ def main():
 
 	global _bootstrapped_dbs
 
-	# verify result hash
 	db = _bootstrapped_dbs[_bootstrapped_dbs.keys()[0]]
+
 	if not db.verify_result_hash():
 		exit_with_msg("Bootstrapping failed: wrong result hash")
 
