@@ -141,7 +141,9 @@ if __name__ == '__main__':
 from Gnumed.pycommon import gmExceptions
 from Gnumed.pycommon import gmPG2
 from Gnumed.pycommon.gmDateTime import pydt_strftime
-from Gnumed.pycommon.gmTools import tex_escape_string, xetex_escape_string
+from Gnumed.pycommon.gmTools import tex_escape_string, xetex_escape_string, compare_dict_likes
+from Gnumed.pycommon.gmTools import xetex_escape_string
+from Gnumed.pycommon.gmTools import compare_dict_likes
 
 
 _log = logging.getLogger('gm.db')
@@ -202,7 +204,7 @@ from Gnumed.pycommon import gmPG2
 #------------------------------------------------------------
 # search/replace "" " -> 3 "s
 #
-# use plural form, search-replace get_XXX
+# search-replace get_XXX, use plural form
 _SQL_get_XXX = u"" "
 	SELECT *, (xmin AS xmin_XXX)
 	FROM XXX.v_XXX
@@ -225,7 +227,10 @@ class cXxxXxx(gmBusinessDBObject.cBusinessDBObject):
 					AND
 				xmin = %(xmin_XXX)s
 			RETURNING
-				xmin as xmin_XXX
+				xmin AS xmin_XXX
+				-- also return columns which are calculated in the view used by
+				-- the initial SELECT such that they will further on contain their
+				-- updated value:
 				--, ...
 				--, ...
 		"" "
@@ -248,7 +253,7 @@ def get_XXX(order_by=None):
 
 	cmd = _SQL_get_XXX % order_by
 	rows, idx = gmPG2.run_ro_queries(queries = [{'cmd': cmd}], get_col_idx = True)
-	return [ cXxxXxx(row = {'data': r, 'idx': idx, 'pk_field': 'pk_xxx'}) for r in rows ]
+	return [ cXxxXxx(row = {'data': r, 'idx': idx, 'pk_field': 'pk_XXX'}) for r in rows ]
 #------------------------------------------------------------
 def create_xxx(xxx=None, xxx=None):
 
@@ -275,8 +280,8 @@ def create_xxx(xxx=None, xxx=None):
 	return cXxxXxx(aPK_obj = rows[0]['pk'])
 	#return cXxxXxx(row = {'data': r, 'idx': idx, 'pk_field': 'pk_XXX'})
 #------------------------------------------------------------
-def delete_xxx(pk_xxx=None):
-	args = {'pk': pk_xxx}
+def delete_xxx(pk_XXX=None):
+	args = {'pk': pk_XXX}
 	cmd = u"DELETE FROM xxx.xxx WHERE pk = %(pk)s"
 	gmPG2.run_rw_queries(queries = [{'cmd': cmd, 'args': args}])
 	return True
@@ -286,7 +291,7 @@ def delete_xxx(pk_xxx=None):
 
 	"""
 	#--------------------------------------------------------
-	def __init__(self, aPK_obj=None, row=None):
+	def __init__(self, aPK_obj=None, row=None, link_obj=None):
 		"""Init business object.
 
 		Call from child classes:
@@ -308,13 +313,13 @@ def delete_xxx(pk_xxx=None):
 		self.__class__._updatable_fields
 
 		if aPK_obj is not None:
-			self.__init_from_pk(aPK_obj=aPK_obj)
+			self.__init_from_pk(aPK_obj = aPK_obj, link_obj = link_obj)
 		else:
 			self._init_from_row_data(row=row)
 
 		self._is_modified = False
 	#--------------------------------------------------------
-	def __init_from_pk(self, aPK_obj=None):
+	def __init_from_pk(self, aPK_obj=None, link_obj=None):
 		"""Creates a new clinical item instance by its PK.
 
 		aPK_obj can be:
@@ -327,7 +332,7 @@ def delete_xxx(pk_xxx=None):
 				the single-value primary key
 		"""
 		self.pk_obj = aPK_obj
-		result = self.refetch_payload()
+		result = self.refetch_payload(link_obj = link_obj)
 		if result is True:
 			self.original_payload = {}
 			for field in self._idx.keys():
@@ -480,7 +485,7 @@ def delete_xxx(pk_xxx=None):
 	#--------------------------------------------------------
 	def fields_as_dict(self, date_format='%Y %b %d  %H:%M', none_string=u'', escape_style=None, bool_strings=None):
 		if bool_strings is None:
-			bools = {True: u'true', False: u'false'}
+			bools = {True: u'True', False: u'False'}
 		else:
 			bools = {True: bool_strings[0], False: bool_strings[1]}
 		data = {}
@@ -498,6 +503,9 @@ def delete_xxx(pk_xxx=None):
 				continue
 
 			if isinstance(val, datetime.datetime):
+				if date_format is None:
+					data[field] = val
+					continue
 				data[field] = pydt_strftime(val, format = date_format, encoding = 'utf8')
 				if escape_style in [u'latex', u'tex']:
 					data[field] = tex_escape_string(data[field])
@@ -527,14 +535,15 @@ def delete_xxx(pk_xxx=None):
 	def format(self):
 		return u'%s' % self
 	#--------------------------------------------------------
-	def refetch_payload(self, ignore_changes=False):
+	def refetch_payload(self, ignore_changes=False, link_obj=None):
 		"""Fetch field values from backend.
 		"""
 		if self._is_modified:
+			compare_dict_likes(self.original_payload, self.fields_as_dict(date_format = None, none_string = None), u'original payload', u'modified payload')
 			if ignore_changes:
 				_log.critical('[%s:%s]: loosing payload changes' % (self.__class__.__name__, self.pk_obj))
-				_log.debug('original: %s' % self.original_payload)
-				_log.debug('modified: %s' % self._payload)
+				#_log.debug('original: %s' % self.original_payload)
+				#_log.debug('modified: %s' % self._payload)
 			else:
 				_log.critical('[%s:%s]: cannot reload, payload changed' % (self.__class__.__name__, self.pk_obj))
 				return False
@@ -544,6 +553,7 @@ def delete_xxx(pk_xxx=None):
 		else:
 			arg = [self.pk_obj]
 		rows, self._idx = gmPG2.run_ro_queries (
+			link_obj = link_obj,
 			queries = [{'cmd': self.__class__._cmd_fetch_payload, 'args': arg}],
 			get_col_idx = True
 		)
@@ -600,10 +610,11 @@ def delete_xxx(pk_xxx=None):
 		if len(rows) == 0:
 			return (False, (u'cannot update row', _('[%s:%s]: row not updated (nothing returned), row in use ?') % (self.__class__.__name__, self.pk_obj)))
 
-		# update cached values from should-be-first-and-only result
-		# row of last query,
+		# update cached values from should-be-first-and-only
+		# result row of last query,
 		# update all fields returned such that computed
-		# columns see their new values
+		# columns see their new values (given they are
+		# returned by the query)
 		row = rows[0]
 		for key in idx:
 			try:
@@ -617,10 +628,14 @@ def delete_xxx(pk_xxx=None):
 				_log.error(args)
 				raise
 
+		# only at conn.commit() time will data actually
+		# get committed (and thusly trigger based notifications
+		# be sent out), so reset the local modification flag
+		# right before that
+		self._is_modified = False
 		conn.commit()
 		close_conn()
 
-		self._is_modified = False
 		# update to new "original" payload
 		self.original_payload = {}
 		for field in self._idx.keys():
