@@ -1,7 +1,6 @@
 __doc__ = """GNUmed general tools."""
 
 #===========================================================================
-__version__ = "$Revision: 1.13 $"
 __author__ = "K. Hilbert <Karsten.Hilbert@gmx.net>"
 __license__ = "GPL v2 or later (details at http://www.gnu.org)"
 
@@ -15,7 +14,6 @@ import shlex
 
 
 _log = logging.getLogger('gm.shell')
-_log.info(__version__)
 
 #===========================================================================
 def is_cmd_in_path(cmd=None):
@@ -27,17 +25,17 @@ def is_cmd_in_path(cmd=None):
 		_log.info('command with full or relative path, not searching in PATH for binary')
 		return (None, None)
 
-	env_paths = os.environ['PATH']
-	_log.debug('${PATH}: %s', env_paths)
+	env_paths = unicode(os.environ['PATH'], encoding = sys.getfilesystemencoding(), errors = 'replace')
+	_log.debug(u'${PATH}: %s', env_paths)
 	for path in env_paths.split(os.pathsep):
-		candidate = os.path.join(path, cmd).encode(sys.getfilesystemencoding())
+		candidate = os.path.join(path, cmd)
 		if os.access(candidate, os.X_OK):
-			_log.debug('found [%s]', candidate)
-			return (True, candidate.decode(sys.getfilesystemencoding()))
+			_log.debug(u'found [%s]', candidate)
+			return (True, candidate)
 		else:
-			_log.debug('not found: %s', candidate)
+			_log.debug(u'not found: %s', candidate)
 
-	_log.debug('command not found in PATH')
+	_log.debug(u'command not found in PATH')
 
 	return (False, None)
 #===========================================================================
@@ -95,6 +93,8 @@ def is_executable_by_wine(cmd=None):
 	return (False, None)
 #===========================================================================
 def detect_external_binary(binary=None):
+	"""<binary> is the name of the executable with or without .exe/.bat"""
+
 	_log.debug('searching for [%s]', binary)
 
 	binary = binary.lstrip()
@@ -159,6 +159,8 @@ def run_command_in_shell(command=None, blocking=False, acceptable_return_codes=N
 	<blocking>
 		This will make the code *block* until the shell command exits.
 		It will likely only work on UNIX shells where "cmd &" makes sense.
+
+	http://stackoverflow.com/questions/35817/how-to-escape-os-system-calls-in-python
 	"""
 	if acceptable_return_codes is None:
 		acceptable_return_codes = [0]
@@ -174,10 +176,10 @@ def run_command_in_shell(command=None, blocking=False, acceptable_return_codes=N
 		# http://stackoverflow.com/questions/893203/bat-files-nonblocking-run-launch
 		if blocking is False:
 			if not command.startswith('start '):
-				command = 'start /B %s' % command
-		elif blocking is True:
-			if not command.startswith('start '):
-				command = 'start /WAIT /B %s' % command
+				command = 'start "GNUmed" /B "%s"' % command
+#		elif blocking is True:
+#			if not command.startswith('start '):
+#				command = 'start "GNUmed" /WAIT /B "%s"' % command
 	else:
 		# what the following hack does is this: the user indicated
 		# whether she wants non-blocking external display of files
